
## CATO-CLI - mutation.sites.removeNetworkRange:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeNetworkRange) for documentation on this operation.

### Usage for mutation.sites.removeNetworkRange:

```bash
catocli mutation sites removeNetworkRange -h

catocli mutation sites removeNetworkRange <json>

catocli mutation sites removeNetworkRange --json-file mutation.sites.removeNetworkRange.json

catocli mutation sites removeNetworkRange '{"networkRangeId":"id"}'

catocli mutation sites removeNetworkRange '{
    "networkRangeId": "id"
}'
```

#### Operation Arguments for mutation.sites.removeNetworkRange ####

`accountId` [ID] - (required) N/A    
`networkRangeId` [ID] - (required) N/A    
